# Beyonic Python Library

The official Python library for interacting with http://beyonic.com API

## Installation

You don't need this source code unless you want to modify the package. If you just want to use the Beyonic Python bindings, you should run:

```python
pip install beyonic
```

or

```python
easy_install beyonic
```

or manually

```python
git clone https://github.com/beyonic/beyonic-python.git
cd beyonic-python
python setup.py install
```

## Usage

Please visit http://support.beyonic.com/api for usage documentation

## Development

Please see DEVELOPMENT.md for information on adding installing requirements, adding new API methods and running tests
